@@ -258,19 +258,20 @@ class SynMem:
         image.show()
 
     # ─── Retrieve ────────────────────────────────────────────────────────
-    def recallMemory(self, query: str, paths: list, user: str = None, type: str = 'Embedding', topK=5, minScore: int = 60, showProgress: bool = False):
+    def recallMemory(self, query: str, paths: list, user: str = None, type: str = 'Embedded', topK=5, minScore: int = 60, showProgress: bool = False):
         type = type.lower()
-        if type == 'embedding':
-            return self.recallMemoryEmbedding(query, paths, user, topK, showProgress)
+        if type in ('embedding', 'embedded'):
+            return self.recallEmbeddedMemory(query, paths, user, topK, showProgress)
         elif type == 'rapid':
-            return self.recallMemoryRapid(query, paths, user, topK, minScore)
+            return self.recallRapidMemory(query, paths, user, topK, minScore)
         else:
-            raise ValueError(f"Unknown recall type: {type}, expected 'embedding' or 'rapid'.")
+            raise ValueError(f"Unknown recall type: {type}, expected 'embedded' or 'rapid'.")
 
-    def recallMemoryEmbedding(self, query: str, paths: list, user: str = None, topK=5, showProgress: bool = False):
+    def recallEmbeddedMemory(self, query: str, paths: list, user: str = None, topK=5, showProgress: bool = False, minScore: int = 60):
         model = self.embeddingModel
         if model is None:
-            raise ValueError("Embedding model not set. Use synmem.setEmbeddingModel(model).")
+            logger.error("Embedding model not set. Falling back to Rapid recall. Use synmem.setEmbeddingModel(model).", exc_info=True)
+            return self.recallRapidMemory(query, paths, user, topK, minScore)
 
         rows = []
         for path in paths:
@@ -299,7 +300,8 @@ class SynMem:
                         # row[0]=dtStamp, row[1]=content, row[2]=response
                         rows.append((row[0], row[1], row[2] if len(row) > 2 else ""))
                 except Exception as ex:
-                    print(f"Error reading for semantic search: {dbFile}: {ex}")
+                    #print(f"Error reading for semantic search: {dbFile}: {ex}")
+                    logger.error(f"Error reading for semantic search: {dbFile}: {ex}", exc_info=True)
                     continue
 
         if not rows:
@@ -316,7 +318,7 @@ class SynMem:
         results = [(rows[i][0], rows[i][1], rows[i][2]) for i in top_indices]
         return results
 
-    def recallMemoryRapid(self, query: str, paths: list, user: str = None, topK=5, minScore: int = 60):
+    def recallRapidMemory(self, query: str, paths: list, user: str = None, topK=5, minScore: int = 60):
         """
         Fuzzy string matching version of recallMemory, using Rapidfuzz.
         Returns topK best-matching (dtStamp, content, response) entries.
@@ -347,7 +349,8 @@ class SynMem:
                     for row in db_rows:
                         rows.append((row[0], row[1], row[2] if len(row) > 2 else ""))
                 except Exception as ex:
-                    print(f"Error reading for fuzzy search: {dbFile}: {ex}")
+                    #print(f"Error reading for fuzzy search: {dbFile}: {ex}")
+                    logger.error(f"Error reading for fuzzy search: {dbFile}: {ex}", exc_info=True)
                     continue
 
         if not rows:
